@@ -4,9 +4,12 @@ from typing import Dict, List, Optional, Union
 import re
 import json
 from .utils import roman_to_int, remove_ns
+from .common import deprecated
 from .client import SruRecord
+import unicodedata
 
 
+@deprecated('Use dedupmarcxml module instead: https://pypi.org/project/dedupmarcxml/')
 class BriefRec:
     """Class representing a brief record object
 
@@ -87,6 +90,7 @@ class BriefRecFactory:
 
         :return: string with normalized title
         """
+        title = unicodedata.normalize('NFC', title)
         title = title.upper().replace('<<', '').replace('>>', '')
         title = re.sub(r'\W', ' ', title)
         title = re.sub(r'\s+', ' ', title).strip()
@@ -103,7 +107,8 @@ class BriefRecFactory:
         """
         extent_lower = extent.lower()
         extent_list = [int(f) for f in re.findall(r'\d+', extent_lower)]
-        extent_list += [roman_to_int(f) for f in re.findall(r'\b[ivxlcdm]+\b', extent_lower)]
+        extent_list += [roman_to_int(f) for f in re.findall(r'\b[ivxlcdm]+\b', extent_lower)
+                        if roman_to_int(f) is not None]
         return extent_list
 
     @staticmethod
@@ -583,6 +588,10 @@ class BriefRecFactory:
         leader6 = BriefRecFactory.get_leader_pos67(bib)[0]
         f008 = bib.find('.//controlfield[@tag="008"]').text
         format_pos = 29 if leader6 in ['e', 'g', 'k', 'o', 'r'] else 23
+        f338b = bib.find('.//datafield[@tag="338"]/subfield[@code="b"]')
+        if f338b is not None and f338b.text == 'cr':
+            return True
+
         return f008[format_pos] in ['o', 'q', 's']
 
 
