@@ -1,3 +1,4 @@
+"""Module to interact with an SRU server"""
 
 import logging
 import requests
@@ -28,13 +29,19 @@ class SruRequest:
     :example:
 
         SruRequest('alma.mms_id=991093571899705501')
-
     """
 
     def __init__(self, query: str,
                  limit: Optional[int] = 10,
                  base_url: Optional[str] = None,
                  is_iz_request: Optional[bool] = False) -> None:
+        """Constructor of SruRequest
+
+        :param query: SRU query string.
+        :param limit: Maximum number of records to return. Default is 10.
+        :param base_url: Base URL of the SRU server.
+        :param is_iz_request: True if the request is for an Institution Zone (IZ).
+        """
         self.query = query
         self.limit = limit
         self.error = False
@@ -46,12 +53,15 @@ class SruRequest:
         self._fetch_records()
 
     def __hash__(self) -> int:
+        """Hash based on query and base_url"""
         return int(hashlib.sha1(bytes(self._get_query_path(), 'utf-8')).hexdigest(), 16)
 
     def __eq__(self, other) -> bool:
+        """Equality comparison based on query and base_url"""
         return self.query == other.query and self.base_url == other.base_url
 
     def __repr__(self) -> str:
+        """String representation of SruRequest"""
         if self.is_iz_request is True:
             return (f"{self.__class__.__name__}('{self.query}', limit={self.limit}, "
                     f"base_url='{self.base_url}', iz_request=True)")
@@ -60,10 +70,19 @@ class SruRequest:
                     f"base_url='{self.base_url}')")
 
     def _get_query_path(self) -> str:
+        """Get a unique string representing the query and base_url combination"""
         return f'{self.base_url}__{self.query}__{self.limit}'
 
     @staticmethod
     def _build_sru_params(query: str, start_record: int = 1, maximum_records: int = 10) -> Dict[AnyStr, AnyStr]:
+        """Build the parameters for an SRU query
+
+        :param query: string containing the sru query
+        :param start_record: int indicating the rank of the first record to fetch
+        :param maximum_records: int indicating the max number of records to fetch, default is 10
+
+        :return: dict with the parameters for the SRU query
+        """
         return {'query': query,
                 'version': '1.2',
                 'operation': 'searchRetrieve',
@@ -120,19 +139,24 @@ class SruRequest:
 
     def _fetch_records(self) -> None:
         """Fetch a list of records from an SRU query
+
+        It iterates to fetch all records until the limit is reached or
+        no more records are available.
         """
 
         records = []
         is_error = False
 
         for i in range(self.limit // 50 + 1):
+
+            # Fetch records in blocks of 50
             start_record = i * 50 + 1
             maximum_records = self.limit - 50 * i if self.limit <= 50 * (i + 1) else 50
 
             xml, is_error = self._fetch_data(start_record, maximum_records)
 
             # Get all records
-            if is_error is True:
+            if is_error:
                 break
 
             rec_number_field = xml.find('.//srw:numberOfRecords', namespaces=SruClient.nsmap)
@@ -147,13 +171,17 @@ class SruRequest:
             if rec_number > self.limit:
                 logging.warning(f'{repr(self)}: number of available results exceed the limit provided')
                 self.are_more_results_available = True
-            if self.is_iz_request is True:
+
+            # Records in IZ or in Network Zone are slightly different
+            # For IZ we need to use IzSruRecord, for NZ SruRecord
+            if self.is_iz_request:
                 new_records = [IzSruRecord(xml=record, base_url=self.base_url) for record
                                in xml.findall('.//m:record', namespaces=SruClient.nsmap)]
             else:
                 new_records = [SruRecord(xml=record, base_url=self.base_url) for record
                                in xml.findall('.//m:record', namespaces=SruClient.nsmap)]
 
+            # No new records found, stop the process
             if len(new_records) == 0:
                 logging.warning(f'No record found for query {self.query}')
                 break
@@ -161,6 +189,7 @@ class SruRequest:
             logging.info(f'Records {start_record} - {start_record + len(new_records) - 1} / {rec_number}'
                          f', "{self.query}": {len(new_records)}')
             records += new_records
+
             if len(records) == rec_number:
                 break
 
@@ -204,6 +233,9 @@ class SruClient:
                  base_url: Optional[str] = None,
                  is_iz_server: Optional[bool] = None) -> None:
         """Construct a new SRU client
+
+        :param base_url: base url of the SRU server
+        :param is_iz_server: flag indicating if the SRU server is related to an IZ
         """
         if base_url is not None:
             self.base_url = base_url
@@ -220,7 +252,7 @@ class SruClient:
     @classmethod
     def clean_old_requests(cls) -> None:
         """Delete and recreate the requests folder and reset the requests and records attributes"""
-        if os.path.isdir('./requests') is True:
+        if os.path.isdir('./requests'):
             shutil.rmtree('./requests')
         os.mkdir('./requests')
 
@@ -258,6 +290,9 @@ class SruRecord:
     Either `xml` or `mms_id` must be provided. If mms_id is provided the constructor
     will fetch the record through SRU query.
 
+    :class:`almasru.client.SruRequest` objects are used to fetch xml data from the SRU server. It will create
+    :class:`almasru.client.SruRecord` objects for each record found, providing the xml data to the constructor.
+
     :ivar mms_id: mms_id of the record to fetch
     :ivar error: boolean, is True in case of error
     :ivar error_messages: list of string with the error messages
@@ -269,7 +304,12 @@ class SruRecord:
     def __init__(self, mms_id: Optional[str] = None,
                  xml: Optional[etree.Element] = None,
                  base_url: Optional[str] = None) -> None:
-        """Constructor of SruRecord"""
+        """Constructor of SruRecord
+
+        :param mms_id: mms_id of the record to fetch
+        :param xml: `etree.Element` containing the Marc XML of the record, optional
+        :param base_url: base url of the SRU server, optional
+        """
         self.mms_id = mms_id
         self.error = False
         self.error_messages = []
@@ -286,7 +326,7 @@ class SruRecord:
 
         elif mms_id is not None and self.error is False:
             r = self.sru_client.fetch_records(f'alma.mms_id={mms_id}')
-            if r.error is True:
+            if r.error:
                 self.error = True
                 self.error_messages += r.error_messages
             else:
@@ -299,26 +339,36 @@ class SruRecord:
 
         self.data = xml
 
-        if self.error is False:
+        if not self.error:
             self.mms_id = self.get_mms_id()
             self.sru_client.records[f'{self.mms_id}_{self.sru_client.base_url}'] = xml
 
     def __str__(self) -> str:
+        """String representation of the record in pretty XML format"""
         if self.data is not None:
             return etree.tostring(self.data, pretty_print=True).decode()
         else:
             return ''
 
     def __repr__(self) -> str:
+        """String representation of SruRecord"""
         return f"{self.__class__.__name__}('{self.mms_id}', base_url='{self.sru_client.base_url}')"
 
     def __hash__(self) -> int:
+        """Hash based on mms_id"""
         return int(self.mms_id)
 
     def __eq__(self, other) -> bool:
+        """Equality comparison based on mms_id"""
         return self.mms_id == other.mms_id
 
-    def _set_sru_client(self, base_url):
+    def _set_sru_client(self, base_url) -> 'SruClient':
+        """Set the SRU client to use
+
+        :param base_url: base url of the SRU server, optional
+
+        :return: :class:`almasru.client.SruClient
+        """
         if base_url is not None:
             return SruClient(base_url=base_url)
         elif SruClient().base_url is not None:
@@ -330,7 +380,12 @@ class SruRecord:
             exit()
 
     def _fetch_parents_by_std_number(self, xml_field: etree.Element) -> List['SruRecord']:
-        """Fetch parents records by standard number"""
+        """Fetch parents records by standard number
+
+        :param xml_field: `etree.Element` containing the Marc XML field to analyse
+
+        :return: list of :class:`almasru.client.SruRecord` representing the parent records
+        """
         # In subfield "x" are ISSN and ISBN
         for subfield_code in ['x', 'z']:
             subfield = xml_field.find(f'./m:subfield[@code="{subfield_code}"]', namespaces=SruClient.nsmap)
@@ -374,8 +429,7 @@ class SruRecord:
 
     @check_error
     def get_mms_id(self) -> Optional[str]:
-        """get_mms_id(self) -> Optional[str]
-        Get MMS_ID of the current record
+        """Get MMS_ID of the current record
 
         :return: string containing the MMS_ID, None in case of error or no data available
         """
@@ -386,12 +440,11 @@ class SruRecord:
 
     @check_error
     def get_035_fields(self, var: bool = False, slsp_only: bool = False) -> Set[str]:
-        """get_035_fields(self, var: bool = False, slsp_only: bool = False) -> Set[str]
-        Return a set of system numbers of 035 fields
+        """Return a set of system numbers of 035 fields
 
         .. note:: Network ID inside 035 is simplified by removing prefix
 
-        :param var: Parameters: flag indicating if truncated system numbers should be tested
+        :param var: Parameters: flag indicating if truncated system numbers should be tested, default is False
         :param slsp_only: Parameters: flag indicating if only slsp system numbers should be returned
 
         :return: Set of strings with the system IDs of 035 fields
@@ -412,7 +465,7 @@ class SruRecord:
 
         if slsp_only is True:
             # return only SLSP related system ids
-            prefixes = '|'.join(['RERO', 'IDSBB', 'IDSLU', 'IDSSG', 'NEBIS', 'SBT', 'ALEX', 'ABN', 'swissbib', 'HAN'])
+            prefixes = '|'.join(['RERO', 'IDSBB', 'IDSLU', 'IDSSG', 'NEBIS', 'SBT', 'ALEX', 'ABN', 'swissbib', 'HAN', 'CMG-HEM'])
             other_sys_ids = {sys_num for sys_num in other_sys_ids
                              if re.match(r'^\((?:{})\).+'.format(prefixes), sys_num)}
 
@@ -429,10 +482,20 @@ class SruRecord:
 
         return other_sys_ids
 
+    
+    @check_error
+    def get_title(self) -> str:
+        """Fetch main Title of the current record
+
+        Fetch the content of 245$$a
+
+        :return: main title
+        """
+        return self.data.findtext('./m:datafield[@tag="245"]/m:subfield[@code="a"]', namespaces=SruClient.nsmap)
+    
     @check_error
     def get_issn(self) -> Set[str]:
-        """get_issn(self) -> Set[str]
-        Fetch ISSN of the current record
+        """Fetch ISSN of the current record
 
         Fetch the content of all 022$$a
 
@@ -444,8 +507,7 @@ class SruRecord:
 
     @check_error
     def get_isbn(self) -> Set[str]:
-        """get_isbn(self) -> Set[str]
-        Fetch ISBN of the current record
+        """Fetch ISBN of the current record
 
         Fetch the content of all 020$$a
 
@@ -457,8 +519,7 @@ class SruRecord:
 
     @check_error
     def get_standard_numbers(self) -> Set[str]:
-        """get_standard_numbers(self) -> Set[str]
-        Fetch all ISSN and ISBN of the records
+        """Fetch all ISSN and ISBN of the records
 
         :return: set of standard numbers
         """
@@ -466,8 +527,7 @@ class SruRecord:
 
     @check_error
     def get_bib_level(self) -> Literal['a', 'b', 'c', 'd', 'i', 'm', 's']:
-        """get_bib_level(self) -> Literal['a', 'b', 'c', 'd', 'i', 'm', 's']
-        Get the bib level of the record
+        """Get the bib level of the record
 
         Fetch the 7th position of the leader field.
 
@@ -478,8 +538,7 @@ class SruRecord:
 
     @check_error
     def get_child_rec(self) -> Dict:
-        """get_child_rec(self) -> Dict
-        check if the records appears in other records
+        """Check if the records appears in other records
 
         Check system numbers and standard numbers to find records that are linked
         to the current record.
@@ -509,8 +568,7 @@ class SruRecord:
 
     @check_error
     def get_child_rec_sys_num(self) -> Dict:
-        """get_child_rec_sys_num(self) -> Dict
-        Check if the given system number appears in other records.
+        """Check if the given system number appears in other records.
 
         :Return: dictionary describing the result of analysis
         """
@@ -596,10 +654,15 @@ class SruRecord:
 
     @check_error
     def get_child_rec_std_num(self) -> Dict:
-        """get_child_rec_std_num(self) -> Dict
-        Check if the given system number appears in other records.
+        """Check if the given system number appears in other records.
 
         :Return: dictionary describing the result of analysis
+
+            * 'MMS_ID':  current record ID
+            * 'related_records_found':  boolean indicating if related records have been found
+            * 'number_of_rel_recs': number of related records found
+            * 'related_records': list of :class:`almasru.client.SruRecords`
+            * 'fields_related_records': list of fields.
         """
         if self._child_rec_std_num is not None:
             return self._child_rec_std_num
@@ -682,13 +745,18 @@ class SruRecord:
 
     @check_error
     def get_parent_rec(self) -> Dict:
-        """get_parent_rec(self) -> Dict
-        Get parents records of the current record
+        """Get parents records of the current record
 
         Uses the content of fields 7xx and 8xx to get all parent records. the method checks standard numbers
         in subfields "x" or "z" and system numbers in "w" subfield.
 
         :return: dictionary describing the result of the analysis
+
+            * 'MMS_ID':  current record ID*
+            * 'related_records_found':  boolean indicating if related records have been found
+            * 'number_of_rel_recs': number of related records found
+            * 'related_records': list of :class:`almasru.client.SruRecords`
+            * 'fields_related_records': list of fields.
         """
         if self._parent_rec is not None:
             return self._parent_rec
@@ -794,13 +862,13 @@ class SruRecord:
 
     @check_error
     def get_inventory_info(self) -> List[Dict]:
-        """get_inventory_info(self) -> List[Dict]
-        Get information about the record in the IZ
+        """Get information about the record in the IZ
 
         The method analyse the 852 fields and returns a list with dictionaries containing:
-        - "IZ": IZ code
-        - "MMS ID": MMS ID of the record in the IZ
-        - "format": format of the record, "P" for print, "E" for electronic, "D" for digital
+
+            * "IZ": IZ code
+            * "MMS ID": MMS ID of the record in the IZ
+            * "format": format of the record, "P" for print, "E" for electronic, "D" for digital
 
         :return: list of records in the IZ linked to the NZ record
         """
@@ -827,8 +895,7 @@ class SruRecord:
 
     @check_error
     def get_iz_using_rec(self) -> List[str]:
-        """get_iz_using_rec(self) -> List[str]
-        Get the list of IZ using this record
+        """Get the list of IZ using this record
 
         This method analyses the 852 fields and returns the list of IZ using the current NZ record.
 
@@ -847,8 +914,7 @@ class SruRecord:
 
     @check_error
     def get_child_analytical_records(self) -> List['SruRecord']:
-        """get_child_analytical_records(self) -> List['SruRecord']
-        Get the list of analytical records. Check only existing 773 fields and not leader.
+        """Get the list of analytical records. Check only existing 773 fields and not leader.
 
         :return: list of :class:`almasru.client.SruRecord`
         """
@@ -1028,11 +1094,11 @@ class SruRecord:
             f.write(str(self))
 
     def get_iz_record(self, server_url: str) -> Optional['IzSruRecord']:
-        """get_iz_record(self, server_url: str) -> Optional['IzSruRecord']
-        Return :class:`almasru.client.IzSruRecord` from provided server url
+        """Fetch IZ record linked to the current NZ record
 
         :param server_url: string with url of the IZ SRU server
-        :return: :class:`almasru.client.IzSruRecord`
+
+        :return: :class:`almasru.client.IzSruRecord` or None if no record found
 
         .. note :: the function doesn't work in all cases. It can only found records with inventory.
         """
@@ -1068,6 +1134,14 @@ class IzSruRecord(SruRecord):
                  xml: Optional[etree.Element] = None,
                  base_url: Optional[str] = None,
                  nz_url: Optional[str] = None) -> None:
+        """Constructor of the class IzSruRecord
+
+        :param mms_id: mms_id of the record to fetch
+        :param xml: string with the XML of the record
+        :param base_url: string with the base url of the IZ SRU server. If None, the default
+            base url of :class:`almasru.client.SruClient` is used
+        :param nz_url: string with the base url of the NZ SRU server. If None, no NZ SRU client is created
+        """
         super().__init__(mms_id, xml, base_url)
         if nz_url is not None:
             self.nz_sru_client = SruClient(base_url=nz_url, is_iz_server=False)
@@ -1075,6 +1149,10 @@ class IzSruRecord(SruRecord):
             self.nz_sru_client = None
 
     def __repr__(self) -> str:
+        """String representation of the object
+
+        :return: string representation of the object
+        """
         if hasattr(self, 'nz_sru_client') and self.nz_sru_client is not None:
             return (f"{self.__class__.__name__}('{self.mms_id}',"
                     f" base_url='{self.sru_client.base_url}',"
@@ -1082,7 +1160,14 @@ class IzSruRecord(SruRecord):
         else:
             return super().__repr__()
 
-    def _set_sru_client(self, base_url):
+    def _set_sru_client(self, base_url) -> 'SruClient':
+        """Set the SRU client for IZ server
+
+        :param base_url: string with the base url of the IZ SRU server. If None, the default
+            base url of :class:`almasru.client.SruClient` is used
+
+        :return: :class:`almasru.client.SruClient` object
+        """
         if base_url is not None:
             return SruClient(base_url=base_url, is_iz_server=True)
         elif SruClient().base_url is not None:
@@ -1095,13 +1180,13 @@ class IzSruRecord(SruRecord):
 
     @check_error
     def get_inventory_info(self) -> List[Dict]:
-        """get_inventory_info(self) -> List[Dict]
-        Get information about the record in the IZ
+        """Get information about the record in the IZ
 
         The method analyse the 852 fields and returns a list with dictionaries containing:
-        - "IZ": IZ code
-        - "MMS ID": MMS ID of the record in the IZ
-        - "format": format of the record, "P" for print, "E" for electronic, "D" for digital
+
+            * "IZ": IZ code
+            * "MMS ID": MMS ID of the record in the IZ
+            * "format": format of the record, "P" for print, "E" for electronic, "D" for digital
 
         :return: list of records in the IZ linked to the NZ record
         """
@@ -1125,7 +1210,9 @@ class IzSruRecord(SruRecord):
                     f[field] = subfield.text
             inventory_info.append(f)
 
-        if len(inventory_info) == 0 and self.nz_sru_client is not None:
+        # Only available items are displayed in AVA fields. For this reason, we need to check if there are
+        # inventory from the NZ SRU request.
+        if len(inventory_info) == 0 and self.nz_sru_client is not None and self.get_nz_mms_id() is not None:
             nz_bib = SruRecord(self.get_nz_mms_id(), base_url=self.nz_sru_client.base_url)
             _ = nz_bib.data
             if nz_bib.error is False:
@@ -1136,10 +1223,10 @@ class IzSruRecord(SruRecord):
         return inventory_info
 
     @check_error
-    def get_nz_mms_id(self):
+    def get_nz_mms_id(self) -> Optional[str]:
         """Fetch MMS ID of the network zone
 
-        :return: MMS ID of the network zone from 035 field
+        :return: MMS ID of the network zone from 035 field or None if not found
         """
         nz_ids_field = self.data.xpath('./m:datafield[@tag="035"]/m:subfield[starts-with(text(), "(EXLNZ")]',
                                        namespaces=SruClient.nsmap)
@@ -1154,17 +1241,17 @@ class IzSruRecord(SruRecord):
 
     @check_error
     def is_removable(self, removable_rec_mms_id: Optional[List[str]] = None) -> Tuple[bool, str]:
-        """is_removable(self, removable_rec_mms_id: Optional[List[str]] = None) -> Tuple[bool, str]
-        Check if a record is safe to be removed
+        """Check if a record is safe to be removed
 
         :param removable_rec_mms_id: list of MMS_ID of records that are safe to be removed. This is used to avoid
             records of the list currently being processed to be considered as preventing deletion.
 
         The method checks related records and inventory in IZ.
-        1. Test if the record has 852 fields. It would indicate existing holding in any IZ
-        2. Test if record has analytical records children (children linked with 773 field)
-        3. Test if the record is target of 8xx or 773 fields of other records
-        4. Test if the record has a 773 field targeting a record with inventory
+
+            1. Test if the record has 852 fields. It would indicate existing holding in any IZ
+            2. Test if record has analytical records children (children linked with 773 field)
+            3. Test if the record is target of 8xx or 773 fields of other records
+            4. Test if the record has a 773 field targeting a record with inventory
 
         :return: tuple containing bool indicating if the record can be safely removed and a message.
         """
@@ -1209,14 +1296,20 @@ class IzSruRecord(SruRecord):
 
         return True, 'REMOVABLE'
 
+    @check_error
     def get_parent_rec(self) -> Dict:
-        """get_parent_rec(self) -> Dict
-        Get parents records of the current record
+        """Get parents records of the current record
 
         Uses the content of fields 7xx and 8xx to get all parent records. the method checks standard numbers
         in subfields "x" or "z" and system numbers in "w" subfield.
 
         :return: dictionary describing the result of the analysis
+
+            * 'MMS_ID':  current record ID*
+            * 'related_records_found':  boolean indicating if related records have been found
+            * 'number_of_rel_recs': number of related records found
+            * 'related_records': list of :class:`almasru.client.SruRecords`
+            * 'fields_related_records': list of fields.
         """
         if self._parent_rec is not None:
             return self._parent_rec
