@@ -194,6 +194,12 @@ class TestDedup(unittest.TestCase):
                          '1 édition',
                          'Should be: "Première edition" => "1 édition"')
 
+    def test_evaluate_isbns(self):
+        isbns_1 = ['9783866480001']
+        isbns_2 = ['3866480001']
+        score = dedup.evaluate_isbns(isbns_1, isbns_2)
+        self.assertGreater(score, 0.9, 'Score should greater 0.9 for variants of same ISBNs')
+
     def test_evaluate_similarity(self):
         mms_id = '991159842549705501'
         rec = SruRecord(mms_id)
@@ -228,32 +234,32 @@ class TestDedup(unittest.TestCase):
                         f'Mean should be less than 0.6 when comparing '
                         f'"{mms_id}" and "{mms_id2}", returned {result}')
 
-    def test_evaluate_similarity_score_2(self):
-        mms_id = '991159842549705501'
-        rec = SruRecord(mms_id)
-        brief_rec = BriefRec(rec)
-        mms_id2 = '991159842549705501'
-        rec2 = SruRecord(mms_id2)
-        brief_rec2 = BriefRec(rec2)
-        with open('classifiers/clf_MLPClassifier_v3.pickle', 'rb') as f:
-            clf = pickle.load(f)
-
-        result = dedup.get_similarity_score(brief_rec.data, brief_rec2.data, clf)
-
-        self.assertGreater(result,
-                           0.98,
-                           f'Result should near to 1.0 when comparing same records, returned {result}')
-
-        mms_id = '991159842549705501'
-        rec = SruRecord(mms_id)
-        brief_rec = BriefRec(rec)
-        mms_id2 = '991159842649705501'
-        rec2 = SruRecord(mms_id2)
-        brief_rec2 = BriefRec(rec2)
-        result = dedup.get_similarity_score(brief_rec.data, brief_rec2.data, clf)
-        self.assertLess(result,
-                        0.5,
-                        f'Result should be less than 0.5 when comparing "{mms_id}" and "{mms_id2}", returned {result}')
+    # def test_evaluate_similarity_score_2(self):
+    #     mms_id = '991159842549705501'
+    #     rec = SruRecord(mms_id)
+    #     brief_rec = BriefRec(rec)
+    #     mms_id2 = '991159842549705501'
+    #     rec2 = SruRecord(mms_id2)
+    #     brief_rec2 = BriefRec(rec2)
+    #     with open('classifiers/clf_MLPClassifier_v3.pickle', 'rb') as f:
+    #         clf = pickle.load(f)
+    #
+    #     result = dedup.get_similarity_score(brief_rec.data, brief_rec2.data, clf)
+    #
+    #     self.assertGreater(result,
+    #                        0.98,
+    #                        f'Result should near to 1.0 when comparing same records, returned {result}')
+    #
+    #     mms_id = '991159842549705501'
+    #     rec = SruRecord(mms_id)
+    #     brief_rec = BriefRec(rec)
+    #     mms_id2 = '991159842649705501'
+    #     rec2 = SruRecord(mms_id2)
+    #     brief_rec2 = BriefRec(rec2)
+    #     result = dedup.get_similarity_score(brief_rec.data, brief_rec2.data, clf)
+    #     self.assertLess(result,
+    #                     0.5,
+    #                     f'Result should be less than 0.5 when comparing "{mms_id}" and "{mms_id2}", returned {result}')
 
 
 if __name__ == '__main__':
